==> key-server-api-0.0.1-20150729.054357-11-sources.jar: com/xdja/cssp/key/server/api/bean/ResultKsfBean.java <==
package com.xdja.cssp.key.server.api.bean;

import java.io.Serializable;

/**
 * 
 * @author 马德成
 * @date 2015年7月15日
 */
public class ResultKsfBean implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	 * ksfId
	 */
	private String ksfId;
	
	/**
	 * Kuep id
	 */
	private Long kuepId;
	/**
	 * 好友账号
	 */
	private String friendAccount;

	/**
	 * 与friendAccount间的会话密钥
	 */
	private String encryptKsf;

	/**
	 * 好友账号会话密钥
	 */
	private String encryptFriendKsf;

	/**
	 * @return 获取encryptFriendKsf
	 */
	public String getEncryptFriendKsf() {
		return encryptFriendKsf;
	}

	/**
	 * @return 获取encryptKsf
	 */
	public String getEncryptKsf() {
		return encryptKsf;
	}

	/**
	 * @return 获取friendAccount
	 */
	public String getFriendAccount() {
		return friendAccount;
	}

	/**
	 * @return 获取ksfId
	 */
	public String getKsfId() {
		return ksfId;
	}

	/**
	 * @return 获取kuepId
	 */
	public Long getKuepId() {
		return kuepId;
	}

	/**
	 * @param 设置encryptFriendKsf
	 */
	public void setEncryptFriendKsf(String encryptFriendKsf) {
		this.encryptFriendKsf = encryptFriendKsf;
	}

	/**
	 * @param 设置encryptKsf
	 */
	public void setEncryptKsf(String encryptKsf) {
		this.encryptKsf = encryptKsf;
	}

	/**
	 * @param 设置friendAccount
	 */
	public void setFriendAccount(String friendAccount) {
		this.friendAccount = friendAccount;
	}

	/**
	 * @param 设置ksfId
	 */
	public void setKsfId(String ksfId) {
		this.ksfId = ksfId;
	}

	/**
	 * @param 设置kuepId
	 */
	public void setKuepId(Long kuepId) {
		this.kuepId = kuepId;
	}
}

==> key-server-api-0.0.1-20151010.022016-17-sources.jar: com/xdja/cssp/key/server/api/bean/ResultKsfBean.java <==
package com.xdja.cssp.key.server.api.bean;

import java.io.Serializable;

/**
 * 
 * @author 马德成
 * @date 2015年7月15日
 */
public class ResultKsfBean implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	 * ksfId
	 */
	private String ksfId;
	
	/**
	 * Kuep id
	 */
	private Long kuepId;
	/**
	 * 好友账号
	 */
	private String friendAccount;

	/**
	 * 与friendAccount间的会话密钥
	 */
	private String encryptKsf;

	/**
	 * 好友账号会话密钥
	 */
	private String encryptFriendKsf;

	/**
	 * @return 获取encryptFriendKsf
	 */
	public String getEncryptFriendKsf() {
		return encryptFriendKsf;
	}

	/**
	 * @return 获取encryptKsf
	 */
	public String getEncryptKsf() {
		return encryptKsf;
	}

	/**
	 * @return 获取friendAccount
	 */
	public String getFriendAccount() {
		return friendAccount;
	}

	/**
	 * @return 获取ksfId
	 */
	public String getKsfId() {
		return ksfId;
	}

	/**
	 * @return 获取kuepId
	 */
	public Long getKuepId() {
		return kuepId;
	}

	/**
	 * @param 设置encryptFriendKsf
	 */
	public void setEncryptFriendKsf(String encryptFriendKsf) {
		this.encryptFriendKsf = encryptFriendKsf;
	}

	/**
	 * @param 设置encryptKsf
	 */
	public void setEncryptKsf(String encryptKsf) {
		this.encryptKsf = encryptKsf;
	}

	/**
	 * @param 设置friendAccount
	 */
	public void setFriendAccount(String friendAccount) {
		this.friendAccount = friendAccount;
	}

	/**
	 * @param 设置ksfId
	 */
	public void setKsfId(String ksfId) {
		this.ksfId = ksfId;
	}

	/**
	 * @param 设置kuepId
	 */
	public void setKuepId(Long kuepId) {
		this.kuepId = kuepId;
	}
	
	@Override
	public String toString() {
		return "ResultKsfBean [ksfId:" + ksfId + ", kuepId:" + kuepId 
				+ ", encryptKsg:" + encryptKsf  + "]";
	}
}
